@@ -192,7 +192,7 @@ class ThermostatPacket(ImazuPacket):
 
     def parse_state_packets(self) -> list:
         """State packet Parse"""
-        if self.value_type == ValueType.MODE:
+        if self.value_type in [ValueType.MODE, ValueType.TEMP]:
             if len(self.state_value) % 3 == 0:
                 # zips 난방분배기 (주)한성시스코, GSTART , 클리오(주)
                 def parse_state(state_value: list[str]):
@@ -435,11 +435,16 @@ class FanPacket(ImazuPacket):
     < f7 0c 01 2b 04 40 11 00 0200 86 ee
     > f7 0b 01 2b 01 41 11 00 00 87 ee
     < f7 0c 01 2b 04 41 11 00 0200 87 ee
+    < f7 0c 01 2b 04 44 11 00 0301 82 ee
 
     - OFF
     > f7 0b 01 2b 02 40 11 02 00 87 ee
     < f7 0c 01 2b 04 41 2b0440 11 00 0207 81 ee
 
+    - AUTO
+    > f7 0b 01 2b 02 40 11 03 00 86 ee
+    < f7 0c 01 2b 04 40 11 03 0301 85 ee
+
     - ON / 1
     > f7 0b 01 2b 02 42 11 01 00 86 ee
     < f7 0c 01 2b 04 41 2b0440 11 00 0101 84 ee
@@ -454,10 +459,11 @@ class FanPacket(ImazuPacket):
     < f7 0c 01 2b 04 41 2b0440 11 00 0107 82 ee
     """
 
-    class Power(Enum):
-        """Fan power"""
-        ON = "01"
+    class Mode(Enum):
+        """Fan mode"""
+        MANUAL = "01"
         OFF = "02"
+        AUTO = "03"
 
     class Speed(Enum):
         """Fan speed"""
@@ -474,11 +480,11 @@ class FanPacket(ImazuPacket):
 
         def parse_state(state_value: list[str]):
             return {
-                'power': FanPacket.Power(state_value[0]),
+                'mode': FanPacket.Mode(state_value[0]),
                 'speed': FanPacket.Speed(state_value[1]),
             }
 
-        if self.value_type in [ValueType.BOOL, ValueType.DIM]:
+        if self.value_type in [ValueType.BOOL, ValueType.DIM, ValueType.SPEED]:
             self.state = parse_state(self.state_value)
             return [self]
 
@@ -500,9 +506,9 @@ class FanPacket(ImazuPacket):
         """Scan packet Make"""
         return super()._make_scan(ValueType.BOOL)
 
-    def make_change_power_off(self) -> bytearray:
-        """Power off packet Make"""
-        return super().make_change(ValueType.BOOL, int(str(FanPacket.Power.OFF.value), 16))
+    def make_change_mode(self, mode: Mode) -> bytearray:
+        """Mode packet Make"""
+        return super().make_change(ValueType.BOOL, int(str(mode.value), 16))
 
     def make_change_speed(self, speed: Speed) -> bytearray:
         """Speed packet Make"""
